@@ -1,9 +1,9 @@
-# Copyright 2001-2006 The Apache Software Foundation or its licensors, as
-# applicable.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -54,7 +54,7 @@ my $passout = "-passout pass:$pass";
 
 # in 0.9.7 s/Email/emailAddress/ in DN
 my $email_field = Apache::Test::normalize_vstring($version) <
-                  Apache::Test::normalize_vstring("0.9.7") ? 
+                  Apache::Test::normalize_vstring("0.9.7") ?
                   "Email" : "emailAddress";
 
 my $ca_dn = {
@@ -214,7 +214,7 @@ emailAddress           = $dn->{$email_field}
 challengePassword      = $pass
 
 [ ca ]
-default_ca	       = CA_default
+default_ca             = CA_default
 
 [ CA_default ]
 certs            = certs        # Where the issued certs are kept
@@ -228,21 +228,22 @@ crl              = $cacrl       # The current CRL
 private_key      = $cakey       # The private key
 
 default_days     = 365          # how long to certify for
-default_crl_days = 30           # how long before next CRL
+default_crl_days = 365          # how long before next CRL
 default_md       = md5          # which md to use.
 preserve         = no           # keep passed DN ordering
 
 [ policy_anything ]
-countryName		= optional
-stateOrProvinceName	= optional
-localityName		= optional
-organizationName	= optional
-organizationalUnitName	= optional
-commonName		= supplied
-emailAddress		= optional
+countryName             = optional
+stateOrProvinceName     = optional
+localityName            = optional
+organizationName        = optional
+organizationalUnitName  = optional
+commonName              = supplied
+emailAddress            = optional
 
 [ comment ]
 nsComment = This Is A Comment
+1.3.6.1.4.1.18060.12.0 = DER:0c064c656d6f6e73
 
 EOF
 
@@ -313,9 +314,12 @@ sub new_cert {
 
 sub sign_cert {
     my $name = shift;
+    my $exts = '';
+
+    $exts = ' -extensions comment' if $name =~ /client_ok/;
 
     openssl ca => "$capolicy -in csr/$name.csr -out certs/$name.crt",
-                  $passin, config($name), '-batch -extensions comment';
+                  $passin, config($name), '-batch', $exts;
 }
 
 #handy for importing into a browser such as netscape
@@ -470,6 +474,13 @@ sub generate {
 
     chdir $base;
 
+    # Ensure the CNs used in the server certs match up with the
+    # hostname being used for testing.
+    while (my($key, $val) = each %$cert_dn) {
+        next unless $key =~ /^server/;
+        $val->{CN} = $Config->{vars}->{servername};
+    }        
+
     #make a note that we created the tree
     $Config->clean_add_path($root);
 
